__all__ = ["characters"]

# 最近更新：鹿野院平藏
characters = {
    # 风
    "琴": "jean",
    "魈": "xiao",
    "温迪": "venti",
    "砂糖": "sucrose",
    "早柚": "sayu",
    "枫原万叶": "kazuha",
    "鹿野院平藏": "heizo",
    # 水
    "莫娜": "mona",
    "行秋": "xingqiu",
    "夜兰": "yelan",
    "芭芭拉": "barbara",
    "达达利亚": "tartaglia",
    "神里绫人": "ayato",
    "珊瑚宫心海": "kokomi",
    # 火
    "可莉": "klee",
    "宵宫": "yoimiya",
    "托马": "thoma",
    "安柏": "amber",
    "香菱": "xiangling",
    "烟绯": "feiyan",
    "辛焱": "xinyan",
    "胡桃": "hutao",
    "班尼特": "bennett",
    "迪卢克": "diluc",
    # 冰
    "重云": "chongyun",
    "凯亚": "kaeya",
    "七七": "qiqi",
    "甘雨": "ganyu",
    "优菈": "eula",
    "申鹤": "shenhe",
    "埃洛伊": "aloy",
    "迪奥娜": "diona",
    "罗莎莉亚": "rosaria",
    "神里绫华": "ayaka",
    # 雷
    "丽莎": "lisa",
    "北斗": "beidou",
    "刻晴": "keqing",
    "雷泽": "razor",
    "菲谢尔": "fischl",
    "久岐忍": "shinobu",
    "九条裟罗": "sara",
    "雷电将军": "shougun",
    "八重神子": "yaemiko",
    # 岩
    "钟离": "zhongli",
    "凝光": "ningguang",
    "五郎": "gorou",
    "云堇": "yunjin",
    "诺艾尔": "noelle",
    "阿贝多": "albedo",
    "荒泷一斗": "itto",
}
